pub struct CameraIntrinsics {
    pub fx: f64,
    pub fy: f64,
    pub cx: f64,
    pub cy: f64,
    pub width: usize,
    pub height: usize,
}
Camera intrinsic parameters.

Fields

fx: f64

Focal length and pixel scale in the X-axis.

fy: f64

Focal length and pixel scale in the Y-axis.

cx: f64

Camera X-center.

cy: f64

Camera Y-center.

width: usize

Image width in pixels.

height: usize

Image height in pixels.

Implementations

source

impl CameraIntrinsics

source

pub fn from_simple_intrinsic( fx: f64, fy: f64, cx: f64, cy: f64, width: usize, height: usize ) -> Self

Create a new camera intrinsic parameters.

Arguments
  • fx: Focal length and pixel scale in the X-axis.
  • fy: Focal length and pixel scale in the Y-axis.
  • cx: Camera X-center.
  • cy: Camera Y-center.
  • width: Image width in pixels.
  • height: Image height in pixels.
Returns
  • A new camera intrinsic parameters.
source

pub fn project(&self, point: &Vector3<f32>) -> (f32, f32)

Project a 3D point into image space.

Arguments
  • point: The 3D point.
Returns
  • (x and y) coordinates.
source

pub fn project_grad(&self, point: &Vector3<f32>) -> ((f32, f32), (f32, f32))

Return the Jacobian of the projection. The Jacobian is the matrix of partial derivatives of the projection function.

Arguments
  • point: The 3D point.
Returns
  • ((dx/dfx, dx/dfy), (dy/dfx, dy/dfy)
source

pub fn backproject(&self, x: f32, y: f32, z: f32) -> Vector3<f32>

Backproject a 2D point into 3D space.

Arguments
  • x: The x coordinate.
  • y: The y coordinate.
  • z: The depth.
Returns
  • The 3D point.
source

pub fn scale(&self, scale: f64) -> Self

Scale the camera parameters according to the given scale.

Arguments
  • scale: The scale factor.
Returns
  • A new camera with scaled parameters.
source

pub fn size(&mut self, width: usize, height: usize)